@@ -1,6 +1,6 @@
 
 /* Define if this is running the Linux operating system.  */
-#undef LINUX
+#define LINUX
 
 /* Define if this is running the SunOS 4.x operating system.  */
 #undef SUNOS4
@@ -28,4 +28,4 @@
 #undef SUNOS4_KERNEL_ARCH_KLUDGE
 
 /* Define if signal.h defines the type sig_atomic_t.  */
-#undef HAVE_SIG_ATOMIC_T
+#define HAVE_SIG_ATOMIC_T
