@@ -69,7 +69,14 @@ int sys_fsync(), sys_clone(), sys_setdomainname(), sys_sysinfo();
 int sys_modify_ldt(), sys_adjtimex(), sys_mprotect();
 int sys_sigprocmask(), sys_create_module(), sys_init_module();
 int sys_delete_module(), sys_get_kernel_syms(), sys_quotactl();
-int sys_getpgid(), sys_fchdir(), sys_bdflush();
+int sys_getpgid(), sys_fchdir(), sys_bdflush(), sys_personality();
+
+int sys_sysfs(), sys_personality(), sys_afs_syscall(), sys_setfsuid();
+int sys_setfsgid(), sys__llseek(), sys_getdents(), sys__newselect();
+int sys_flock(), sys_syscall_flock(), sys_msync(), sys_readv();
+int sys_syscall_readv(), sys_writev(), sys_syscall_writev();
+int sys_getsid();
+
 
 /* sys_socketcall subcalls */
 
@@ -78,7 +85,7 @@ int sys_accept(), sys_getsockname(), sys_getpeername(), sys_socketpair();
 int sys_send(), sys_recv(), sys_sendto(), sys_recvfrom();
 int sys_shutdown(), sys_setsockopt(), sys_getsockopt();
 
-#define SYS_socket_subcall	150
+#define SYS_socket_subcall	180	/* WTA: was 150? */
 #define SYS_socket		(SYS_socket_subcall + 1)
 #define SYS_bind		(SYS_socket_subcall + 2)
 #define SYS_connect		(SYS_socket_subcall + 3)
@@ -103,7 +110,7 @@ int sys_semget(), sys_semctl();
 int sys_msgsnd(), sys_msgrcv(), sys_msgget(), sys_msgctl();
 int sys_shmat(), sys_shmdt(), sys_shmget(), sys_shmctl();
 
-#define SYS_ipc_subcall		170
+#define SYS_ipc_subcall		200 /* WTA: was 170? */
 #define SYS_semop		(SYS_ipc_subcall + 1)
 #define SYS_semget		(SYS_ipc_subcall + 2)
 #define SYS_semctl		(SYS_ipc_subcall + 3)
