@@ -74,7 +74,21 @@ static struct xlat mmap_flags[] = {
 	{ MAP_PRIVATE,	"MAP_PRIVATE"	},
 	{ MAP_FIXED,	"MAP_FIXED"	},
 #ifdef MAP_ANONYMOUS
-	{ MAP_FIXED,	"MAP_ANONYMOUS"	},
+/* 	{ MAP_FIXED,	"MAP_ANONYMOUS"	}, */
+       { MAP_ANONYMOUS,        "MAP_ANONYMOUS" },
+#endif
+/* Some Linux specific flags */
+#ifdef MAP_GROWSDOWN
+       { MAP_GROWSDOWN,        "MAP_GROWSDOWN" },
+#endif
+#ifdef MAP_DENYWRITE
+       { MAP_DENYWRITE,        "MAP_DENYWRITE" },
+#endif
+#ifdef MAP_EXECUTABLE
+       { MAP_EXECUTABLE,       "MAP_EXECUTABLE" },
+#endif
+#ifdef MAP_LOCKED
+       { MAP_LOCKED,           "MAP_LOCKED" },
 #endif
 #ifdef MAP_RENAME
 	{ MAP_RENAME,	"MAP_RENAME"	},
