@@ -32,6 +32,15 @@
  *
  *	syscall.c,v 2.25 1994/03/12 23:11:57 jrs Exp
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#ifdef LINUX
+#define __KERNEL__
+#include <errno.h>
+#undef __KERNEL__
+#endif
 
 #include "defs.h"
 
