@@ -474,8 +474,6 @@ char *laddr;
 {
 
 #ifdef LINUX
-	if (tcp->pfd == -2)
-		return -1;
 	if (tcp->pfd == -1) {
 		char buf[32];
 
@@ -483,12 +481,41 @@ char *laddr;
 		if ((tcp->pfd = open(buf, O_RDONLY)) == -1) {
 			perror(buf);
 			tcp->pfd = -2;
+		}
+	}
+	if (tcp->pfd != -2) {
+		lseek(tcp->pfd, addr, 0);
+		if (read(tcp->pfd, laddr, len) == -1) {
+			/* read somehow failed, switch to alternative method */
+			tcp->pfd = -2;
 			return -1;
 		}
 	}
-	lseek(tcp->pfd, addr, 0);
-	if (read(tcp->pfd, laddr, len) == -1)
-		return -1;
+	if (tcp->pfd == -2) {
+		/* WTA: proc-filesystem failed, so we resort to ptrace.
+		 * copied from the SunOS oldway code. 
+		 */
+		int pid = tcp->pid;
+		int n, m;
+		union {
+			int val;
+			char x[4];
+		} u;
+	
+		if (addr & 3) {
+			/* addr not a multiple of 4 */
+			n = addr - (addr & -4); /* residue */
+			addr &= -4; /* residue */
+			u.val = ptrace(PTRACE_PEEKDATA, pid, (char *) addr, 0);
+			memcpy(laddr, &u.x[n], m = MIN(4 - n, len));
+			addr += 4, laddr += m, len -= m;
+		}
+		while (len) {
+			u.val = ptrace(PTRACE_PEEKDATA, pid, (char *) addr, 0);
+			memcpy(laddr, u.x, m = MIN(4, len));
+			addr += 4, laddr += m, len -= m;
+		}
+	}
 #endif /* LINUX */
 
 #ifdef SUNOS4
